# :fire: `ebtorch` <a href="https://ballarin.cc/cdn/ebtorch_dalle2.png"><img src="https://ballarin.cc/cdn/ebtorch_dalle2.png" align="right" height="139" /></a>

Collection of [PyTorch](https://pytorch.org/) additions, extensions, utilities, *uses and abuses*... for personal use.
